@@ -3,4 +3,4 @@
 __author__ = """Tyler F. Carr"""
 __email__ = "tcarwash@gmail.com"
 __version__ = "0.1.0"
-from . import cli, swpclib
+from . import cli, swpclib, alerts
